==> gpstk1.3.src.tar.gz: gpstk/src/YumaAlmanacStore.cpp <==
#pragma ident "$Id: YumaAlmanacStore.cpp 383 2007-01-30 16:23:29Z ehagen $"

//============================================================================
//
//  This file is part of GPSTk, the GPS Toolkit.
//
//  The GPSTk is free software; you can redistribute it and/or modify
//  it under the terms of the GNU Lesser General Public License as published
//  by the Free Software Foundation; either version 2.1 of the License, or
//  any later version.
//
//  The GPSTk is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with GPSTk; if not, write to the Free Software Foundation,
//  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//  
//  Copyright 2004, The University of Texas at Austin
//
//============================================================================
//============================================================================
//
//This software developed by Applied Research Laboratories at the University of
//Texas at Austin, under contract to an agency or agencies within the U.S. 
//Department of Defense. The U.S. Government retains all rights to use,
//duplicate, distribute, disclose, or release this software. 
//
//Pursuant to DoD Directive 523024 
//
// DISTRIBUTION STATEMENT A: This software has been approved for public 
//                           release, distribution is unlimited.
//
//=============================================================================

/**
 * @file YumaAlmanacStore.cpp
 * Store Yuma almanac information, and access by satellite and time
 */

#include "YumaAlmanacStore.hpp"

namespace gpstk
{
   void YumaAlmanacStore::loadFile(const std::string& filename)
      throw(gpstk::FileMissingException)
   {
      try
      {
         YumaStream strm(filename.c_str());
         if (!strm)
         {
            FileMissingException e("File " + filename + " could not be opened.");
            GPSTK_THROW(e);
         }
         
         YumaHeader header;
         strm >> header;
         addFile(filename, header);

         YumaData rec;
         while(strm >> rec)
	 {
	    addAlmanac(AlmOrbit(rec));
         }  
	 
      }
      catch (gpstk::Exception& e)
      {
         GPSTK_RETHROW(e);
      }
   
   }
   
   gpstk::DayTime YumaAlmanacStore::getFinalTime() 
      const
   {
      DayTime retDT = DayTime::BEGINNING_OF_TIME;
      UBAMap::const_iterator satItr = uba.begin();
      while (satItr != uba.end())
      {
         const EngAlmMap& eam = (*satItr).second;

         EngAlmMap::const_iterator nextItr;
         for (nextItr=eam.begin(); nextItr!=eam.end(); ++nextItr)
         {
            const AlmOrbit& ao = (*nextItr).second;
            try 
            {
               DayTime testT = ao.getToaTime();
               if (testT<retDT) retDT = testT;
            }
               // Not to worry, worst case method return 'BEGINNING_OF_TIME'
            catch(...)
            {}
         }
         satItr++;
      }
      return(retDT);
   }
   
}

==> gpstk-1.7.src.tar.gz: gpstk/src/YumaAlmanacStore.cpp <==
#pragma ident "$Id: YumaAlmanacStore.cpp 1034 2008-01-16 15:50:20Z renfroba $"

//============================================================================
//
//  This file is part of GPSTk, the GPS Toolkit.
//
//  The GPSTk is free software; you can redistribute it and/or modify
//  it under the terms of the GNU Lesser General Public License as published
//  by the Free Software Foundation; either version 2.1 of the License, or
//  any later version.
//
//  The GPSTk is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with GPSTk; if not, write to the Free Software Foundation,
//  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//  
//  Copyright 2004, The University of Texas at Austin
//
//============================================================================
//============================================================================
//
//This software developed by Applied Research Laboratories at the University of
//Texas at Austin, under contract to an agency or agencies within the U.S. 
//Department of Defense. The U.S. Government retains all rights to use,
//duplicate, distribute, disclose, or release this software. 
//
//Pursuant to DoD Directive 523024 
//
// DISTRIBUTION STATEMENT A: This software has been approved for public 
//                           release, distribution is unlimited.
//
//=============================================================================

/**
 * @file YumaAlmanacStore.cpp
 * Store Yuma almanac information, and access by satellite and time
 */

#include "YumaAlmanacStore.hpp"

namespace gpstk
{

   void YumaAlmanacStore::loadFile(const std::string& filename)
      throw(FileMissingException)
   {
      try
      {
         YumaStream strm(filename.c_str());
         if (!strm)
         {
            FileMissingException e("File " + filename + " could not be opened.");
            GPSTK_THROW(e);
         }
         
         YumaHeader header;
         strm >> header;
         addFile(filename, header);

         YumaData rec;
         while(strm >> rec)
	      {
               // If the user has indcated a time of interest and
               // the reference week number is less than 10 bits long, 
               // assume the almanac must be within 511 weeks of the 
               // time of interest
               // If necessary, adjust the GPS week number
            if (timeOfInterest>gpstk::DayTime::BEGINNING_OF_TIME &&
                rec.week < 1024)
            {
               short diff = timeOfInterest.GPSfullweek() - rec.week;
               short nEpochs = (diff+512) / 1024;
               rec.week += nEpochs * 1024;
            }
	         addAlmanac(AlmOrbit(rec));
         }	 
      }
      catch (gpstk::Exception& e)
      {
         GPSTK_RETHROW(e);
      }   
   }

}
